@@ -10,8 +10,9 @@
 #
 
 import argparse
+import struct
+import wave
 
-import soundfile
 from pvcheetah import *
 
 
@@ -20,16 +21,21 @@ def main():
     parser.add_argument('--access_key', required=True)
     parser.add_argument('--library_path', default=None)
     parser.add_argument('--model_path', default=None)
-    parser.add_argument('--audio_paths', nargs='+', required=True)
+    parser.add_argument('--wav_paths', nargs='+', required=True)
     args = parser.parse_args()
 
     o = create(access_key=args.access_key, library_path=args.library_path, model_path=args.model_path)
 
     try:
-        for audio_path in args.audio_paths:
-            audio, sample_rate = soundfile.read(audio_path, dtype='int16')
-            if sample_rate != o.sample_rate:
-                raise ValueError('Cheetah can only process audio data with sample rate of `%d`' % o.sample_rate)
+        for wav_path in args.wav_paths:
+            with wave.open(wav_path, 'rb') as f:
+                if f.getframerate() != o.sample_rate:
+                    raise ValueError(
+                        f"invalid sample rate of `{f.getframerate()}`. cheetah only accepts `{o.sample_rate}`")
+                if f.getnchannels() != 1:
+                    raise ValueError("this demo can only process single-channel WAV files")
+                buffer = f.readframes(f.getnframes())
+                audio = struct.unpack('%dh' % (len(buffer) / struct.calcsize('h')), buffer)
 
             num_frames = len(audio) // o.frame_length
             transcript = ''
@@ -42,6 +48,8 @@ def main():
             print(final_transcript)
     except CheetahActivationLimitError:
         print(f"AccessKey `{args.access_key}` has reached it's processing limit.")
+    finally:
+        o.delete()
 
 
 if __name__ == '__main__':
